@@ -1,13 +1,14 @@
 import argparse
 import sys
 
-import protview.cds_extraction_args as cds_extraction
-import protview.gen_coords_args as gen_coords
-import protview.junction_peptides_args as junction_peptides
-import protview.junction_summary_args as junction_summary
-import protview.rpg_output_processing_args as rpg_output_processing
-import protview.summary_stats_args as summary_stats
-import protview.unique_count_args as unique_count
+import cds_extraction_args as cds_extraction
+import gen_coords_args as gen_coords
+import junction_peptides_args as junction_peptides
+import junction_summary_args as junction_summary
+import rpg_output_processing_args as rpg_output_processing
+import summary_stats_args as summary_stats
+import unique_count_args as unique_count
+import replace_underscores_args as replace_underscores
 
 # make a parser in this with help options etc
 parser = argparse.ArgumentParser(prog='ProtView',
@@ -51,6 +52,11 @@ unique_count_subparser = subparsers.add_parser("unique_count",
                                                parents=[unique_count.parser])
 unique_count_subparser.set_defaults(func="unique_count")
 
+#replace underscores parser
+replace_underscores_subparser = subparsers.add_parser("replace_underscores",
+                                               parents = [replace_underscores.parser])
+replace_underscores_subparser.set_defaults(func="replace_underscores")
+
 
 def main():
     args = parser.parse_args()
@@ -80,6 +86,9 @@ def main():
     elif args.func == "unique_count":
         unique_count.parser = parser
         unique_count.main()
+    elif args.func == "replace_underscores":
+        replace_underscores.parser = parser
+        replace_underscores.main()
 
 
 if __name__ == '__main__':
